#ifndef xmod_h
#define xmod_h

#include <windows.h>


#pragma pack (push, 1)


#ifdef __cplusplus
extern "C" {
#endif


    /*
    // Value of XMOD_HEADER.Sign
    */

#define XMOD_HEADER_SIGN                0x444F4D58

    /*
    // XMOD_HEADER.Flags:
    // If the XMOD_HEADER_FLAG_STARTUPINFO flag is no set then the 
    // user can choose between startup/nonstartup load modes, but
    // if it is set then the XMOD_HEADER_FLAG_STARTUP flag determines
    // the correct load mode overriding the users choice.
    */

#define XMOD_HEADER_FLAG_STARTUPINFO    0x01
#define XMOD_HEADER_FLAG_STARTUP        0x02

typedef struct _XMOD_HEADER {
    DWORD   Sign;               /* "XMOD": XMOD_HEADER_SIGN */
    BYTE    Version;            /* A single digit XMOD version number. Zero for current version */
    BYTE    Flags;              /* XMOD_HEADER_FLAG_XXX constants */
    DWORD   Secret1;            /* Guess :) */
    DWORD   Secret2;            /* ;D */
    DWORD   SizeInfo;           /* The size of the info block that follows this header. */
} XMOD_HEADER;


    /*
    // Structure of the info block:
    // The info block consists of variable length sub blocks. All of
    // these block has an XMOD_INFO_HEADER that is followed by variable
    // length data. If the data contains text then DOS/Windows type
    // newlines must be used (CR/LF: 13,10). Newlines will be used only
    // when they are necessary and the text may contain a full big
    // paragraph without a single newline character, so you should
    // display the text with auto-wordbreak.
    */

typedef struct _XMOD_INFO_HEADER {
    DWORD   ID;                 /* One of the XMOD_INFO_XXX constants */
    DWORD   Size;               /* The size of the data that follows this header. */
} XMOD_INFO_HEADER;


    /*
    // XMOD_INFO_HEADER.ID
    //
    // XMOD_INFO_NAME: Name of the plugin.
    // XMOD_INFO_VERSION: Plugin version string.
    // XMOD_INFO_DESCRIPTION: Brief description of the plugin.
    // XMOD_INFO_AUTHOR: Author of the plugin.
    // XMOD_INFO_CONTACT: How to contact the author.
    // XMOD_INFO_TIME: Build tme of the plugin.
    // XMOD_INFO_COMPANY: Company.
    // XMOD_INFO_URL: Webpage of the company/plugin.
    // XMOD_INFO_COPYRIGHT: Copyrigth string.
    // XMOD_INFO_USAGE: Long description/usage of the plugin.
    // XMOD_INFO_LANGUAGE: Language of the plugin.
    */

#define XMOD_INFO_NAME              0x454D414E
#define XMOD_INFO_VERSION           0x20524556
#define XMOD_INFO_DESCRIPTION       0x43534544
#define XMOD_INFO_AUTHOR            0x48545541
#define XMOD_INFO_CONTACT           0x544E4F43
#define XMOD_INFO_TIME              0x454D4954
#define XMOD_INFO_COMPANY           0x504D4F43
#define XMOD_INFO_URL               0x204C5255
#define XMOD_INFO_COPYRIGHT         0x59504F43
#define XMOD_INFO_USAGE             0x20455355
#define XMOD_INFO_LANGUAGE          0x474E414C
#define XMOD_INFO_ORIGFILENAME      0x454C4946




#ifdef __cplusplus
}
#endif


#pragma pack (pop)


#endif  /* xmod_h */


