#include <stdio.h>
#include "xmod.h"


FILE    *f    = NULL;
char    *data = NULL;


struct {
    DWORD   dwID;
    char    *lpszIDName;
} IDNames[] =
{
    { XMOD_INFO_NAME,           "Plugin name" },
    { XMOD_INFO_VERSION,        "Version" },
    { XMOD_INFO_DESCRIPTION,    "Description" },
    { XMOD_INFO_AUTHOR,         "Author" },
    { XMOD_INFO_CONTACT,        "Contact" },
    { XMOD_INFO_TIME,           "Build time" },
    { XMOD_INFO_COMPANY,        "Company" },
    { XMOD_INFO_URL,            "URL" },
    { XMOD_INFO_COPYRIGHT,      "Copyright" },
    { XMOD_INFO_USAGE,          "Usage" },
    { XMOD_INFO_LANGUAGE,       "Language" },
    { XMOD_INFO_ORIGFILENAME,   "Original filename" },
    { 0 }
};


void quit (char *msg)
{
    if (msg)
    {
        printf (msg);
        printf ("\n");
    }

    if (f) fclose (f);
    if (data) free (data);

    exit (0);
}

int main (int argc, char **argv)
{
    XMOD_HEADER         header;
    XMOD_INFO_HEADER    *pinfo;
    DWORD               dwConsumed = 0;
    int                 i;
    char                *print_buff;

    if (argc != 2) quit ("Usage: xmod_info <xmod_filename>");

    if (!(f = fopen (argv[1], "rb")))
        quit ("Error opeining XMOD file!");

    if (fread (&header, 1, sizeof (header), f) != sizeof (header))
        quit ("Error reading XMOD header!");

    if (header.Sign != XMOD_HEADER_SIGN ||
        header.Version != 0)
        quit ("Invalid XMOD file!");

    printf ("Load mode: ");
    
    if (header.Flags & XMOD_HEADER_FLAG_STARTUPINFO)
    {
        if (header.Flags & XMOD_HEADER_FLAG_STARTUP)
            printf ("Startup\n");
        else
            printf ("Nonstartup\n");
    }
    else
    {
        printf ("User defined\n");
    }

    if (!header.SizeInfo) quit ("There is no info in this XMOD.");

    if (!(data = (char*)malloc (header.SizeInfo)))
        quit ("Out of memory.");

    if (fread (data, 1, header.SizeInfo, f) != header.SizeInfo)
        quit ("Error reading info from the XMOD!");

    pinfo = (XMOD_INFO_HEADER*)data;

    printf ("Info blocks in %s:\n", argv[1]);

    for (;;)
    {
        dwConsumed += sizeof (XMOD_INFO_HEADER);
        if (dwConsumed > header.SizeInfo) quit (NULL);
        dwConsumed += pinfo->Size;
        if (dwConsumed > header.SizeInfo) quit (NULL);

        for (i=0; IDNames[i].lpszIDName; i++)
            if (pinfo->ID == IDNames[i].dwID) break;

        printf ("\n---------------------------------\n");

        if (IDNames[i].lpszIDName)
        {
            printf ("%s:\n", IDNames[i].lpszIDName);
            if (!(print_buff = (char*)malloc (pinfo->Size + 1)))
                quit ("Out of memory.");
            memcpy (print_buff, pinfo + 1, pinfo->Size);
            print_buff[pinfo->Size] = 0;
            printf ("%s\n", print_buff);
            free (print_buff);
        }
        else
        {
            printf ("Unknown info block. (ID: %#8.8x)\n", pinfo->ID);
        }

        pinfo = (XMOD_INFO_HEADER*)((char*)pinfo + sizeof (XMOD_INFO_HEADER) + pinfo->Size);
    }

    return 0;
}

